@@ -1,4 +1,6 @@
-`permControl`<- function(cm=NULL,nmc=10^3-1,seed=1234321,digits=12,p.conf.level=.99,setSEED=TRUE){
+`permControl`<- function(cm=NULL,nmc=10^3-1,seed=1234321,
+    digits=12,p.conf.level=.99,setSEED=TRUE,
+    tsmethod="central"){
     if (!is.numeric(nmc) || nmc <= 0) 
         stop("value of 'nmc' must be > 0")
     if (!is.numeric(digits) || digits <= 0) 
@@ -12,5 +14,10 @@
     if (!is.logical(setSEED)){
         stop(" setSEED must be logical")
     }
-    list(cm=cm,nmc=nmc,seed=seed,digits=digits,p.conf.level=p.conf.level,setSEED=setSEED)    
+    if (!(class(tsmethod)=="character" & (tsmethod=="central" | tsmethod=="abs"))){
+        stop(" tsmethod must be 'central' or 'abs' ")
+    }
+    list(cm=cm,nmc=nmc,seed=seed,digits=digits,
+        p.conf.level=p.conf.level,setSEED=setSEED,
+        tsmethod=tsmethod)    
 }
