@@ -13,7 +13,7 @@ library(perm)
 y<-c(1.11,2.22,3.33,0,100,1)
 g<-as.factor(c(1,1,0,0,1,0))
 independence_test(y~g,distribution=exact())
-permTS(y~g,method="exact.ce",alternative="two.sidedAbs")
+permTS(y~g,method="exact.ce",alternative="two.sided",control=permControl(tsmethod="abs"))
 independence_test(y~g,distribution=exact(),alternative="less")
 permTS(y~g,method="exact.ce",alternative="less")
 independence_test(y~g,distribution=exact(),alternative="greater")
@@ -21,4 +21,4 @@ permTS(y~g,method="exact.ce",alternative="greater")
 
 y<-4.44*y
 independence_test(y~g,distribution=exact())
-permTS(y~g,method="exact.ce",alternative="two.sidedAbs")
\ No newline at end of file
+permTS(y~g,method="exact.ce",alternative="two.sided",control=permControl(tsmethod="abs"))
\ No newline at end of file
